==> kubernetes-model-admissionregistration-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValidatingWebhookConfigurationFluentImpl<A extends ValidatingWebhookConfigurationFluent<A>> extends BaseFluent<A> implements ValidatingWebhookConfigurationFluent<A>{
  public ValidatingWebhookConfigurationFluentImpl() {
  }
  public ValidatingWebhookConfigurationFluentImpl(ValidatingWebhookConfiguration instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withWebhooks(instance.getWebhooks()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ArrayList<ValidatingWebhookBuilder> webhooks = new ArrayList<ValidatingWebhookBuilder>();
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadata() {
    return new ValidatingWebhookConfigurationFluentImpl.MetadataNestedImpl();
  }
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ValidatingWebhookConfigurationFluentImpl.MetadataNestedImpl(item);
  }
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ValidatingWebhookConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public A addToWebhooks(Integer index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(index >= 0 ? index : _visitables.get("webhooks").size(), builder);this.webhooks.add(index >= 0 ? index : webhooks.size(), builder); return (A)this;
  }
  public A setToWebhooks(Integer index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= _visitables.get("webhooks").size()) { _visitables.get("webhooks").add(builder); } else { _visitables.get("webhooks").set(index, builder);}
    if (index < 0 || index >= webhooks.size()) { webhooks.add(builder); } else { webhooks.set(index, builder);}
     return (A)this;
  }
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A addAllToWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder);if (this.webhooks != null) {this.webhooks.remove(builder);}} return (A)this;
  }
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items) {
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder);if (this.webhooks != null) {this.webhooks.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate) {
    if (webhooks == null) return (A) this;
    final Iterator<ValidatingWebhookBuilder> each = webhooks.iterator();
    final List visitables = _visitables.get("webhooks");
    while (each.hasNext()) {
      ValidatingWebhookBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhook> getWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  public List<ValidatingWebhook> buildWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  public ValidatingWebhook buildWebhook(Integer index) {
    return this.webhooks.get(index).build();
  }
  public ValidatingWebhook buildFirstWebhook() {
    return this.webhooks.get(0).build();
  }
  public ValidatingWebhook buildLastWebhook() {
    return this.webhooks.get(webhooks.size() - 1).build();
  }
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withWebhooks(List<ValidatingWebhook> webhooks) {
    if (this.webhooks != null) { _visitables.get("webhooks").removeAll(this.webhooks);}
    if (webhooks != null) {this.webhooks = new ArrayList(); for (ValidatingWebhook item : webhooks){this.addToWebhooks(item);}} else { this.webhooks = null;} return (A) this;
  }
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks) {
    if (this.webhooks != null) {this.webhooks.clear();}
    if (webhooks != null) {for (ValidatingWebhook item :webhooks){ this.addToWebhooks(item);}} return (A) this;
  }
  public Boolean hasWebhooks() {
    return webhooks != null && !webhooks.isEmpty();
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhook() {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl();
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item) {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl(-1, item);
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> setNewWebhookLike(Integer index,ValidatingWebhook item) {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl(index, item);
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editWebhook(Integer index) {
    if (webhooks.size() <= index) throw new RuntimeException("Can't edit webhooks. Index exceeds size.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editFirstWebhook() {
    if (webhooks.size() == 0) throw new RuntimeException("Can't edit first webhooks. The list is empty.");
    return setNewWebhookLike(0, buildWebhook(0));
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editLastWebhook() {
    int index = webhooks.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last webhooks. The list is empty.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public ValidatingWebhookConfigurationFluent.WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    int index = -1;
    for (int i=0;i<webhooks.size();i++) { 
    if (predicate.test(webhooks.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching webhooks. No match found.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValidatingWebhookConfigurationFluentImpl that = (ValidatingWebhookConfigurationFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (webhooks != null ? !webhooks.equals(that.webhooks) :that.webhooks != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  webhooks,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (webhooks != null && !webhooks.isEmpty()) { sb.append("webhooks:"); sb.append(webhooks + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ValidatingWebhookConfigurationFluent.MetadataNested<N>> implements ValidatingWebhookConfigurationFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class WebhooksNestedImpl<N> extends ValidatingWebhookFluentImpl<ValidatingWebhookConfigurationFluent.WebhooksNested<N>> implements ValidatingWebhookConfigurationFluent.WebhooksNested<N>,Nested<N>{
    WebhooksNestedImpl(Integer index,ValidatingWebhook item) {
      this.index = index;
      this.builder = new ValidatingWebhookBuilder(this, item);
    }
    WebhooksNestedImpl() {
      this.index = -1;
      this.builder = new ValidatingWebhookBuilder(this);
    }
    ValidatingWebhookBuilder builder;
    Integer index;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluentImpl.this.setToWebhooks(index,builder.build());
    }
    public N endWebhook() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/ValidatingWebhookConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValidatingWebhookConfigurationFluentImpl<A extends ValidatingWebhookConfigurationFluent<A>> extends BaseFluent<A> implements ValidatingWebhookConfigurationFluent<A>{
  public ValidatingWebhookConfigurationFluentImpl() {
  }
  public ValidatingWebhookConfigurationFluentImpl(ValidatingWebhookConfiguration instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withWebhooks(instance.getWebhooks());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ArrayList<ValidatingWebhookBuilder> webhooks = new ArrayList<ValidatingWebhookBuilder>();
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ValidatingWebhookConfigurationFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ValidatingWebhookConfigurationFluentImpl.MetadataNestedImpl();
  }
  public ValidatingWebhookConfigurationFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ValidatingWebhookConfigurationFluentImpl.MetadataNestedImpl(item);
  }
  public ValidatingWebhookConfigurationFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ValidatingWebhookConfigurationFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ValidatingWebhookConfigurationFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public A addToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").add(index, builder); webhooks.add(index, builder);}
    return (A)this;
  }
  public A setToWebhooks(int index,ValidatingWebhook item) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);
    if (index < 0 || index >= webhooks.size()) { _visitables.get("webhooks").add(builder); webhooks.add(builder); } else { _visitables.get("webhooks").set(index, builder); webhooks.set(index, builder);}
    return (A)this;
  }
  public A addToWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A addAllToWebhooks(Collection<ValidatingWebhook> items) {
    if (this.webhooks == null) {this.webhooks = new ArrayList<ValidatingWebhookBuilder>();}
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").add(builder);this.webhooks.add(builder);} return (A)this;
  }
  public A removeFromWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... items) {
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder);if (this.webhooks != null) {this.webhooks.remove(builder);}} return (A)this;
  }
  public A removeAllFromWebhooks(Collection<ValidatingWebhook> items) {
    for (ValidatingWebhook item : items) {ValidatingWebhookBuilder builder = new ValidatingWebhookBuilder(item);_visitables.get("webhooks").remove(builder);if (this.webhooks != null) {this.webhooks.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromWebhooks(Predicate<ValidatingWebhookBuilder> predicate) {
    if (webhooks == null) return (A) this;
    final Iterator<ValidatingWebhookBuilder> each = webhooks.iterator();
    final List visitables = _visitables.get("webhooks");
    while (each.hasNext()) {
      ValidatingWebhookBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildWebhooks instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingWebhook> getWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  public List<ValidatingWebhook> buildWebhooks() {
    return webhooks != null ? build(webhooks) : null;
  }
  public ValidatingWebhook buildWebhook(int index) {
    return this.webhooks.get(index).build();
  }
  public ValidatingWebhook buildFirstWebhook() {
    return this.webhooks.get(0).build();
  }
  public ValidatingWebhook buildLastWebhook() {
    return this.webhooks.get(webhooks.size() - 1).build();
  }
  public ValidatingWebhook buildMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    for (ValidatingWebhookBuilder item: webhooks) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withWebhooks(List<ValidatingWebhook> webhooks) {
    if (this.webhooks != null) { _visitables.get("webhooks").clear();}
    if (webhooks != null) {this.webhooks = new ArrayList(); for (ValidatingWebhook item : webhooks){this.addToWebhooks(item);}} else { this.webhooks = null;} return (A) this;
  }
  public A withWebhooks(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ValidatingWebhook... webhooks) {
    if (this.webhooks != null) {this.webhooks.clear(); _visitables.remove("webhooks"); }
    if (webhooks != null) {for (ValidatingWebhook item :webhooks){ this.addToWebhooks(item);}} return (A) this;
  }
  public Boolean hasWebhooks() {
    return webhooks != null && !webhooks.isEmpty();
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> addNewWebhook() {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl();
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> addNewWebhookLike(ValidatingWebhook item) {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl(-1, item);
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> setNewWebhookLike(int index,ValidatingWebhook item) {
    return new ValidatingWebhookConfigurationFluentImpl.WebhooksNestedImpl(index, item);
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> editWebhook(int index) {
    if (webhooks.size() <= index) throw new RuntimeException("Can't edit webhooks. Index exceeds size.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> editFirstWebhook() {
    if (webhooks.size() == 0) throw new RuntimeException("Can't edit first webhooks. The list is empty.");
    return setNewWebhookLike(0, buildWebhook(0));
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> editLastWebhook() {
    int index = webhooks.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last webhooks. The list is empty.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public ValidatingWebhookConfigurationFluentImpl.WebhooksNested<A> editMatchingWebhook(Predicate<ValidatingWebhookBuilder> predicate) {
    int index = -1;
    for (int i=0;i<webhooks.size();i++) { 
    if (predicate.test(webhooks.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching webhooks. No match found.");
    return setNewWebhookLike(index, buildWebhook(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValidatingWebhookConfigurationFluentImpl that = (ValidatingWebhookConfigurationFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(webhooks, that.webhooks)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  webhooks,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (webhooks != null && !webhooks.isEmpty()) { sb.append("webhooks:"); sb.append(webhooks + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ValidatingWebhookConfigurationFluentImpl.MetadataNested<N>> implements ValidatingWebhookConfigurationFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class WebhooksNestedImpl<N> extends ValidatingWebhookFluentImpl<ValidatingWebhookConfigurationFluentImpl.WebhooksNested<N>> implements ValidatingWebhookConfigurationFluentImpl.WebhooksNested<N>,Nested<N>{
    WebhooksNestedImpl(int index,ValidatingWebhook item) {
      this.index = index;
      this.builder = new ValidatingWebhookBuilder(this, item);
    }
    WebhooksNestedImpl() {
      this.index = -1;
      this.builder = new ValidatingWebhookBuilder(this);
    }
    ValidatingWebhookBuilder builder;
    int index;
    public N and() {
      return (N) ValidatingWebhookConfigurationFluentImpl.this.setToWebhooks(index,builder.build());
    }
    public N endWebhook() {
      return and();
    }
    
  }
  
}
